/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useContext, useState} from 'react';
import { Button } from '@material-ui/core';
import Modal from '@material-ui/core/Modal';
import Backdrop from '@material-ui/core/Backdrop';
import Fade from '@material-ui/core/Fade';
import styled from 'styled-components'
import {Store} from '../Store.js'
import axios from 'axios'
import {apiUrl} from '../env';
import CloseIcon from '@material-ui/icons/Close';

const StyledModal = styled(Modal)`
    display : flex;
    align-items: center;
    justify-content : center;
    text-align : center;
    padding : 10px !important;
`

export default function ModalConfirmarProfessor (props){
    const {state, dispatch} = useContext(Store)
    return (

        <StyledModal
            aria-labelledby="transition-modal-title"
            aria-describedby="transition-modal-description"
            open={props.open}
            animation={true}
            centered={true}
            onClose={props.handleClose}
            closeAfterTransition
            BackdropComponent={Backdrop}
            BackdropProps={{
                timeout: 500,
            }}
         >
            <Fade in={props.open} style={{ transitionDelay :"0.4ms"}}>
                <>
                    <ConfirmarProfessorComponent>
                        <HeaderDiv>
                            <span style={{width:"32px"}}/>
                            <h2>Confirme os Dados</h2>
                            <Button style={{marginRight:"-8px", color:"000"}} onClick={props.handleClose}>
                                <CloseIcon style={{color:"#666", cursor:"pointer", verticalAlign:"middle"}}/>
                            </Button>
                        </HeaderDiv>

                        <DialogContentDiv>
                            <ContainerCentralized>
                                <p><strong>Município - UF:</strong> {props.info.school_uf.abbreviation} - {props.info.school_city.name} </p>
                                <p><strong>Escola:</strong> {props.info.school_name}</p>
                                <p><strong>Telefone da Escola:</strong> {props.info.school_phone}</p>
                                <p><strong>Seu CPF:</strong> {props.info.teacher_cpf}</p>
                                <ButtonsDiv>
                                    <ConfirmButton onClick ={props.confirmar}>CONFIRMAR</ConfirmButton>
                                    <CancelButton onClick = {props.cancelar}>CANCELAR</CancelButton>
                                </ButtonsDiv>
                            </ContainerCentralized>
                        </DialogContentDiv>
                    </ConfirmarProfessorComponent>
                </>
            </Fade>
        </StyledModal>

    )
}

const CancelButton = styled(Button)`
    width : 140px !important;
    color :#666 !important;
    font-family : Roboto,sans-serif !important;
    font-size : 14px !important;
    font-weight : 500 !important;
    height : 36px !important;
    border-radius : 3px !important;
    padding-left : 16px !important;
    padding-right : 16px !important;
    outline : none !important;
    margin : 6px 8px !important;
    display : inline-block !important;
`

const ConfirmButton = styled(Button)`
    width : 140px !important;
    background-color : #00bcd4 !important;
    color :  #fff !important;
    font-family : Roboto,sans-serif !important;
    font-size : 14px !important;
    font-weight : 500 !important;
    height : 36px !important;
    border-radius : 3px !important;
    padding-left : 32px !important;
    padding-right : 32px !important;
    outline : none !important;
    margin : 6px 8px !important;
    display : inline-block !important;
`

const ButtonsDiv = styled.div`
    margin-top : 10px;
    display : flex;
    justify-content : center;
`


const ContainerCentralized = styled.div`
    margin-top : 0;
    padding-left : 20px;
    padding-right : 30px;

    p {
        font-size : 15px;
        margin : 0 0 10px;
    }
`

const DialogContentDiv = styled.div`
    padding : 20px 30px;
    overflow : visible !important;
`

const HeaderDiv = styled.div`
    text-align : center;
    display : flex;
    justify-content : space-between;
    padding : 10px 26px 0 26px;

    h2 {
        font-size : 26px;
        font-weight : lighter;
    }
`

const ConfirmarProfessorComponent = styled.div`
    min-width : 600px;
    border-radius : 4px;
    background-color : #fff;
    color : #666;
`
