import React, {useState, useEffect} from 'react'
import {Content, ButtonsArea} from './PartOne.js'
import Divider from '@material-ui/core/Divider';
import Stepper from '../Stepper.js'
import CustomizedTables from '../Table.js'
import styled from 'styled-components'
import {Button} from '@material-ui/core'
import axios from 'axios'
import {simcaqAPIurl} from '../../env'
import {sortDict} from './PartOne.js'

export default function PartTwo (props) {
    const [schoolList, setSchoolList] = useState([])

    useEffect ( () => {
        const code = (props.info.inep_code || '')
        const uf = (props.info.school_uf.id || '')
        const municipio = (props.info.school_City.id || '')
        //console.log(code, uf, municipio)

        //if user searched by inep code
        if (code !== '') {
            axios.get((`${simcaqAPIurl}/portal_mec_inep?filter=school_cod:` + code)
        ).then ((response) => {
            setSchoolList(sortDict(response.data.result))
        }, (error) => console.log('erro ao dar get na escola por inep code')
        )}
        else if (uf !== '' && municipio !== '') {
            axios.get((`${simcaqAPIurl}/school?filter=state:"` + uf + '",city:"' + municipio + '",year:2017')
        ).then((response)=> {
            //console.log(response.data.result)
            setSchoolList(sortDict(response.data.result))
        }, (error) => console.log('erro ao dar get na escola por uf e municipio', code, uf, municipio)
        )}
    }, [])

    const onClickTable = (city_name, id, name, state_name) => {
        props.handleBuscar(city_name, id, name, state_name)
    }

    return (
        <>
        {console.log(props)}
            <Content>
                <h4>Vamos localizar o seu cadastro:</h4>
                <Stepper items={props.stepper}/>
            </Content>
            <Content>
                <InputContainer>
                    <p>Selecione a sua escola:</p>

                            <CustomizedTables
                            columns={['Codigo INEP', 'Escola', 'UF', 'Cidade']}
                            rows={schoolList} onClickTable={onClickTable}
                            />

                </InputContainer>
            </Content>
            <Divider/>
            <ButtonsArea>
                <ButtonGrey onClick={() => props.goBack(true, false, false)}>VOLTAR</ButtonGrey>
                <ButtonCancelar onClick={props.handleCancelar}>CANCELAR VERIFICAÇÃO</ButtonCancelar>
            </ButtonsArea>
        </>
    )
}

export const ButtonCancelar = styled(Button)`
    color: #666 !important;
    font-family: 'Roboto',sans-serif !important;
    font-size: 14px !important;
    font-weight: bold !important;
    height: 36px !important;
    border-radius: 3px !important;
    padding-left: 16px !important;
    padding-right: 16px !important;
`

export const ButtonGrey = styled(Button)`
    background-color : #fff !important;
    border : 1.5px #666 solid !important;
    color : #666 !important;
    box-shadow : none !important;
    font-family : 'Roboto',sans-serif !important;
    font-size : 14px !important;
    font-weight : bold !important;
    height : 36px !important;
    border-radius : 3px !important;
    padding-left : 16px !important;
    padding-right : 16px !important;
    vertical-align : middle !important;
    text-align : center !important;
    align-items : center !important;

`

const InputContainer = styled.div`
    max-width : 970px;
    display : block;
    flex : auto;
`
